@@ -2,7 +2,7 @@ from django.contrib.admin.sites import AdminSite
 from django.utils.text import capfirst
 
 
-VERSION = (0, 1, 5)
+VERSION = (0, 1, 6)
 __version__ = '.'.join([str(x) for x in VERSION])
 
 
@@ -11,7 +11,7 @@ class AdminSitePlus(AdminSite):
     index_template = 'adminplus/index.html'  # That was easy.
     custom_views = []
 
-    def register_view(self, path, view, name=None):
+    def register_view(self, path, view, name=None, urlname=None, visible=True):
         """Add a custom admin view.
 
         * `path` is the path in the admin where the view will live, e.g.
@@ -19,16 +19,20 @@ class AdminSitePlus(AdminSite):
         * `view` is any view function you can imagine.
         * `name` is an optional pretty name for the list of custom views. If
             empty, we'll guess based on view.__name__.
+        * `urlname` is an optional parameter to be able to call the view with a
+            redirect() or reverse()
+        * `visible` is a boolean to set if the custom view should be visible in
+            the admin dashboard or not.
         """
-        self.custom_views.append((path, view, name))
+        self.custom_views.append((path, view, name, urlname, visible))
 
     def get_urls(self):
         """Add our custom views to the admin urlconf."""
         urls = super(AdminSitePlus, self).get_urls()
         from django.conf.urls.defaults import patterns, url
-        for path, view, name in self.custom_views:
+        for path, view, name, urlname, visible in self.custom_views:
             urls += patterns('',
-                url(r'^%s$' % path, self.admin_view(view)),
+                url(r'^%s$' % path, self.admin_view(view), name=urlname),
             )
         return urls
 
@@ -36,9 +40,14 @@ class AdminSitePlus(AdminSite):
         """Make sure our list of custom views is on the index page."""
         if not extra_context:
             extra_context = {}
-        custom_list = [(path, name if name else
-                        capfirst(view.__name__)) for path, view, name in
-                        self.custom_views]
+        custom_list = []
+        for path, view, name, urlname, visible in self.custom_views:
+            if visible is True:
+                if name:
+                    custom_list.append((path, name))
+                else:
+                    custom_list.append(path, capfirst(view.__name__))
+
         # Sort views alphabetically.
         custom_list.sort(key=lambda x: x[1])
         extra_context.update({
